@@ -4,7 +4,7 @@
 #' If \code{x} is already a data.frame, it is returned as is. If it is
 #' a list or a vector it is converted by means of \code{as.data.frame()}.
 #' If of any other type, a conversion into an object of class \code{xts} is
-#' attempted by means of \code{try.xts()} and if succesful the \code{xts}
+#' attempted by means of \code{try.xts()} and if successful the \code{xts}
 #' object is converted into a data frame with a variable \code{time}
 #' containing times as \code{POSIXct} and the remaining data columns with
 #' the time series data. In this conversion row names are stripped.
@@ -17,8 +17,8 @@
 #'
 #' @return A \code{tibble::tibble} object, derived from \code{data.frame}.
 #'
-#' @note This function can be used to easily converttime series data into a
-#'   format that can be easily plotted with pacakge \code{ggplot2}.
+#' @note This function can be used to easily convert time series data into a
+#'   format that can be easily plotted with package \code{ggplot2}.
 #'   \code{try_tibble} is another name for \code{try_data_frame} which tracks
 #'   the separation and re-naming of \code{data_frame} into
 #'   \code{tibble::tibble} in the imported packages.
@@ -29,7 +29,7 @@
 #'   apply a conversion before printing or plotting time data, which in addition
 #'   is affected by summer/winter time transitions. This should be taken into
 #'   account as even for yearly data when conversion is to POSIXct a day (1st of
-#'   Jannuary) will be set, but then shifted some hours if printed on a TZ
+#'   January) will be set, but then shifted some hours if printed on a TZ
 #'   different from "UTC". I recommend reading the documentation of package
 #'   \code{\link[lubridate]{lubridate}} where the irregularities of time data
 #'   and the difficulties they cause are very well described. In many cases when
@@ -72,7 +72,7 @@ try_data_frame <- function(x,
     times <- as.POSIXct(times.raw) # handles conversion from classes in xts and zoo
   }
   if (lubridate::tz(times) == "") {
-    times <- lubridate::with_tz(times, tz = "UTC")
+    times <- lubridate::with_tz(times, "UTC")
   }
   if (is.null(names(x))) {
     data.names <- paste("V.", as.character(substitute(x)), sep = "")
